@@ -1,3 +1,12 @@
+#  File R/bayesmbc.R in package latentnet, part of the Statnet suite
+#  of packages for network analysis, http://statnet.org .
+#
+#  This software is distributed under the GPL-3 license.  It is free,
+#  open source, and has the attribution requirements (GPL Section 7) at
+#  http://statnet.org/attribution
+#
+#  Copyright 2003-2014 Statnet Commons
+#######################################################################
 bayesmbc<-function(G,Z,prior,Z.K.ref=NULL,sample.size=2000,interval=10,burnin=500,verbose=FALSE){
   start<-mbc.VII.EM(G,Z)
   state<-start<-with(start,list(Z=Z,
@@ -30,7 +39,7 @@ bayesmbc<-function(G,Z,prior,Z.K.ref=NULL,sample.size=2000,interval=10,burnin=50
 }
 
 bayesmbc.snowFT<-function(threads,G,Z,prior,Z.K.ref=NULL,sample.size=2000,interval=10,burnin=500,verbose=FALSE){
-  if(!require(snowFT)) stop("Package 'snowFT' required for multithreaded model based clustering MCMC.")
+  if(!requireNamespace("snowFT",quietly=TRUE)) stop("Package 'snowFT' required for multithreaded model based clustering MCMC.")
   start<-mbc.VII.EM(G,Z)
   state<-start<-with(start,list(Z=Z,
                                 Z.mean=Z.mean,
