@@ -1,3 +1,12 @@
+#  File R/label.switching.R in package latentnet, part of the Statnet suite
+#  of packages for network analysis, http://statnet.org .
+#
+#  This software is distributed under the GPL-3 license.  It is free,
+#  open source, and has the attribution requirements (GPL Section 7) at
+#  http://statnet.org/attribution
+#
+#  Copyright 2003-2014 Statnet Commons
+#######################################################################
 klswitch.C <- function(Q.start,sample,Z=NULL,maxit=100,verbose=0)
 {
   
@@ -62,7 +71,7 @@ klswitch.snowFT<-function(threads,Q.start,sample,Z=NULL,maxit=100,verbose=0){
   if(!all(dim(Q.start)==c(n,G))) stop("Incorrect dimensions for initial Q matrix.")
   
 
-  if(!require(snowFT)) stop("Package 'snowFT' is required for multithreaded KL Switching.")
+  if(!requireNamespace("snowFT",quietly=TRUE)) stop("Package 'snowFT' is required for multithreaded KL Switching.")
   
   Cret <- .C("klswitch_pK_wrapper",
              S = as.integer(S),
@@ -98,10 +107,10 @@ klswitch.snowFT<-function(threads,Q.start,sample,Z=NULL,maxit=100,verbose=0){
 
     best.perms.l<-{
       if(threads==1)
-        list(klswitch.step2.snowFT.slave(1,lib=path.to.me,Q=Q,pK.l=pK.l))
-      else performParallel(threads,1:threads,
+        list(klswitch.step2.snowFT.slave(1,lib=.latentnetEnv$path.to.me,Q=Q,pK.l=pK.l))
+      else snowFT::performParallel(threads,1:threads,
                            klswitch.step2.snowFT.slave,
-                           lib=path.to.me,
+                           lib=.latentnetEnv$path.to.me,
                            Q=Q,
                            pK.l=pK.l)
     }
