@@ -1,8 +1,17 @@
+/*  File src/ergmm_updaters.h in package latentnet, part of the Statnet suite
+ *  of packages for network analysis, http://statnet.org .
+ *
+ *  This software is distributed under the GPL-3 license.  It is free,
+ *  open source, and has the attribution requirements (GPL Section 7) at
+ *  http://statnet.org/attribution
+ *
+ *  Copyright 2003-2014 Statnet Commons
+ */
 #ifndef ERGMM_UPDATERS_H
 #define ERGMM_UPDATERS_H
 
 #include "ergmm_structs.h"
-void ERGMM_MCMC_propose(ERGMM_MCMC_Model *model, ERGMM_MCMC_MCMCState *cur, unsigned int Z, unsigned int RE, unsigned int coef, unsigned int LV, unsigned int REV);
+void ERGMM_MCMC_propose(ERGMM_MCMC_Model *model, ERGMM_MCMC_MCMCState *cur, unsigned int Z, unsigned int RE, unsigned int coef, unsigned int LV, unsigned int REV, unsigned int dispersion);
 /* The main difference between accepting and rejecting is the direction, so
    they are just macros. (The other main difference is whether lpedge needs
    to be copied.)
